@@ -128,7 +128,7 @@ extern "C" {
 #define GETDNS_NUMERIC_VERSION 0x01070200
 #define GETDNS_API_VERSION "December 2015"
 #define GETDNS_API_NUMERIC_VERSION 0x07df0c00
-#define GETDNS_BUILD_CFLAGS "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -flto=auto -D_POSIX_C_SOURCE=200112L -D_XOPEN_SOURCE=600 -D_BSD_SOURCE -D_DEFAULT_SOURCE -O3 -DNDEBUG"
+#define GETDNS_BUILD_CFLAGS "-march=x86-64-v4 -O3 -pipe -fno-plt -fexceptions -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security -fstack-clash-protection -fcf-protection -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -mpclmul -g -ffile-prefix-map=/startdir/src=/usr/src/debug/getdns -flto=auto -falign-functions=32 -D_POSIX_C_SOURCE=200112L -D_XOPEN_SOURCE=600 -D_BSD_SOURCE -D_DEFAULT_SOURCE -O3 -DNDEBUG"
 /** @}
   */
 
